@@ -57,9 +57,7 @@ void xdebug_library_minit(void)
 	xdebug_set_opcode_multi_handler(ZEND_ASSIGN);
 	xdebug_set_opcode_multi_handler(ZEND_ASSIGN_DIM);
 	xdebug_set_opcode_multi_handler(ZEND_ASSIGN_OBJ);
-#if PHP_VERSION_ID >= 70400
 	xdebug_set_opcode_multi_handler(ZEND_ASSIGN_STATIC_PROP);
-#endif
 	xdebug_set_opcode_multi_handler(ZEND_QM_ASSIGN);
 	xdebug_set_opcode_multi_handler(ZEND_INCLUDE_OR_EVAL);
 }
@@ -122,7 +120,7 @@ void xdebug_disable_opcache_optimizer(void)
 }
 
 
-static int xdebug_lib_set_mode_item(char *mode, int len)
+static int xdebug_lib_set_mode_item(const char *mode, int len)
 {
 	if (strncmp(mode, "off", len) == 0) {
 		XG_LIB(mode) |= XDEBUG_MODE_OFF;
@@ -156,11 +154,11 @@ static int xdebug_lib_set_mode_item(char *mode, int len)
 	return 0;
 }
 
-static int xdebug_lib_set_mode_from_setting(char *mode)
+static int xdebug_lib_set_mode_from_setting(const char *mode)
 {
-	char *mode_ptr = mode;
-	char *comma    = NULL;
-	int   errors   = 0;
+	const char *mode_ptr = mode;
+	char       *comma    = NULL;
+	int         errors   = 0;
 
 	XG_LIB(mode) = 0;
 
@@ -178,7 +176,7 @@ static int xdebug_lib_set_mode_from_setting(char *mode)
 	return !errors;
 }
 
-int xdebug_lib_set_mode(char *mode)
+int xdebug_lib_set_mode(const char *mode)
 {
 	char *config = getenv("XDEBUG_MODE");
 	int   result = 0;
@@ -757,6 +755,10 @@ void xdebug_lib_register_compiled_variables(function_stack_entry *fse, zend_op_a
 		fse->declared_vars = xdebug_llist_alloc(xdebug_declared_var_dtor);
 	}
 
+	if (!op_array->vars) {
+		return;
+	}
+
 	/* gather used variables from compiled vars information */
 	while (i < (unsigned int) op_array->last_var) {
 		xdebug_llist_insert_next(fse->declared_vars, XDEBUG_LLIST_TAIL(fse->declared_vars), xdebug_str_create(STR_NAME_VAL(op_array->vars[i]), STR_NAME_LEN(op_array->vars[i])));
